@@ -101,7 +101,7 @@ class Experiment:
         """
         results = self.repo.drop(
             collection=self.collection,
-            query={"inExperiment": True},
+            query={"inExperiment": {"$exists": True}},
             return_result=True,
         )
         if results["acknowledged"] and confirm_msg:
