@@ -111,14 +111,22 @@ class FakeRepository(AbstractRepository):
 
     def drop(self, collection: str, query: dict, return_result=False):
         deleted_count = 0
-        ((key, val),) = query.items()
         new_collection = []
-        for d in self.db[collection]:
-            if (key not in d) or (d[key] != val):
-                new_collection.append(d)
-            else:
-                deleted_count += 1
-            self.db[collection] = new_collection
+        # Need special case for using MongoDB operator for resetting experiment
+        if ("inExperiment" in query) and ("$exists" in query["inExperiment"]):
+            for d in self.db[collection]:
+                if "inExperiment" not in d:
+                    new_collection.append(d)
+                else:
+                    deleted_count += 1
+        else:
+            ((key, val),) = query.items()
+            for d in self.db[collection]:
+                if (key not in d) or (d[key] != val):
+                    new_collection.append(d)
+                else:
+                    deleted_count += 1
+        self.db[collection] = new_collection
         if return_result:
             return {"acknowledged": True, "deleted_count": deleted_count}
 
